==> randomForestSRC_3.0.1.tar.gz: randomForestSRC/R/predict.rfsrc.R <==
predict.rfsrc <-
  function(object,
           newdata,
           m.target = NULL,
           importance = c(FALSE, TRUE, "none", "anti", "permute", "random"),
           get.tree = NULL,
           block.size = if (any(is.element(as.character(importance), c("none", "FALSE")))) NULL else 10,
           na.action = c("na.omit", "na.impute"),
           outcome = c("train", "test"),
           perf.type = NULL,
           proximity = FALSE,
           forest.wt = FALSE,
           ptn.count = 0,
           distance = FALSE,
           var.used = c(FALSE, "all.trees", "by.tree"),
           split.depth = c(FALSE, "all.trees", "by.tree"),
           seed = NULL,
           do.trace = FALSE,
           membership = FALSE,
           statistics = FALSE,
            
           ...)
{
  result.predict <- generic.predict.rfsrc(object,
                                          newdata,
                                          m.target = m.target,
                                          importance = importance,
                                          get.tree = get.tree,                                          
                                          block.size = block.size,
                                          na.action = na.action,
                                          outcome = outcome,
                                          perf.type = perf.type,
                                          proximity = proximity,
                                          forest.wt = forest.wt,
                                          ptn.count = ptn.count,
                                          distance = distance,                                          
                                          var.used = var.used,
                                          split.depth = split.depth,
                                          seed = seed,
                                          do.trace = do.trace,
                                          membership = membership,
                                          statistics = statistics,
                                           
                                          ...)
  return(result.predict)
}

==> randomForestSRC_3.1.1.tar.gz: randomForestSRC/R/predict.rfsrc.R <==
predict.rfsrc <-
  function(object,
           newdata,
           m.target = NULL,
           importance = c(FALSE, TRUE, "none", "anti", "permute", "random"),
           get.tree = NULL,
           block.size = if (any(is.element(as.character(importance), c("none", "FALSE")))) NULL else 10,
           na.action = c("na.omit", "na.impute", "na.random"),
           outcome = c("train", "test"),
           perf.type = NULL,
           proximity = FALSE,
           forest.wt = FALSE,
           ptn.count = 0,
           distance = FALSE,
           var.used = c(FALSE, "all.trees", "by.tree"),
           split.depth = c(FALSE, "all.trees", "by.tree"),
           seed = NULL,
           do.trace = FALSE,
           membership = FALSE,
           statistics = FALSE,
            
           ...)
{
  result.predict <- generic.predict.rfsrc(object,
                                          newdata,
                                          m.target = m.target,
                                          importance = importance,
                                          get.tree = get.tree,                                          
                                          block.size = block.size,
                                          na.action = na.action,
                                          outcome = outcome,
                                          perf.type = perf.type,
                                          proximity = proximity,
                                          forest.wt = forest.wt,
                                          ptn.count = ptn.count,
                                          distance = distance,                                          
                                          var.used = var.used,
                                          split.depth = split.depth,
                                          seed = seed,
                                          do.trace = do.trace,
                                          membership = membership,
                                          statistics = statistics,
                                           
                                          ...)
  return(result.predict)
}
